<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AboutWindow</name>
    <message>
        <location filename="../../src/ui/about.ui" line="19"/>
        <source>About QAntenna</source>
        <translation>O QAntenna</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="103"/>
        <source>&amp;About</source>
        <translation>&amp;O programie</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="145"/>
        <source>A&amp;uthors</source>
        <translation>A&amp;utorzy</translation>
    </message>
    <message utf8="true">
        <location filename="../../src/ui/about.ui" line="157"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Lisandro Damián Nicanor Pérez Meyer&lt;br /&gt;&lt;a href=&quot;perezmeyer@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;perezmeyer@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;Gustavo Gonzalez&lt;br /&gt;&lt;a href=&quot;gonzalgustavo@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;gonzalgustavo@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;Pablo Odorico&lt;br /&gt;&lt;a href=&quot;gonzalgustavo@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;pablo.odorico@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Lisandro Damián Nicanor Pérez Meyer&lt;br /&gt;&lt;a href=&quot;perezmeyer@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;perezmeyer@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;Gustavo Gonzalez&lt;br /&gt;&lt;a href=&quot;gonzalgustavo@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;gonzalgustavo@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;Pablo Odorico&lt;br /&gt;&lt;a href=&quot;gonzalgustavo@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;pablo.odorico@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="180"/>
        <source>&amp;Thanks To</source>
        <translation>&amp;Podziękowania</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="242"/>
        <source>&amp;License Agreement</source>
        <translation>&amp;Licencja</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="254"/>
        <source>This program is distributed under the terms of the  GNU General Public License Version 2&lt;br&gt;&lt;br&gt;Available &lt;a href=&quot;http://www.gnu.org/copyleft/gpl.html&quot;&gt;online&lt;/a&gt; or in the COPYING file.</source>
        <translation>Ten program jeest dyystrybuowany na  zasadach licencji GNU/GPL w wersji 2&lt;br&gt;&lt;br&gt; dostępnej na stronie &lt;a href=&quot;http://www.gnu.org/copyleft/gpl.html&quot;&gt;www.gnu.org&lt;/a&gt; lub w pliku COPYING.</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="90"/>
        <source>&lt;version&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="115"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;QAntenna&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;A multiplatform antenna and radiation pattern analyzer&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://qantenna.sf.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://qantenna.sf.net/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="198"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:12pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Joop Stakenborg&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Correct installation of translation files in UNIX systems&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Dutch Translation&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Testing&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Michael Barjenbruch&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - INSTALL file&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - German translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Louis Belmont&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - French translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Marcin Gucia&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Polish translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Marina Goritskaia&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Russian translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Peter Isaksen&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt; - Danish translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Marc Ume&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Original yagi8sq_ch1.nec example&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Everaldo&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Icons&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Claudio Delrieux&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;Ricardo Coppo&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;Gustavo Ramoscelli&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;T.C.A. Molteno&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;N. Kyriazis&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;See examples/LICENSE-NEC.FILES for more information on the NEC examples&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DataManager</name>
    <message>
        <location filename="../../src/datamanager.cpp" line="248"/>
        <source>Closing</source>
        <translation>Zamykanie</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="273"/>
        <source>NEC files (*.nec)</source>
        <translation>Pliki NEC (*.nec)</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="273"/>
        <source>All files (*.*)</source>
        <translation>Wszystkie pliki (*.*)</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="292"/>
        <source>The file &quot;</source>
        <translation>Plik &quot;</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="292"/>
        <source>&quot; is already open.</source>
        <translation>&quot; jest już otwarty.</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="313"/>
        <source>Opening</source>
        <translation>Otwieranie</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="86"/>
        <source>Calculating</source>
        <translation>Obliczanie</translation>
    </message>
</context>
<context>
    <name>GLWidget</name>
    <message>
        <location filename="../../src/glwidget.cpp" line="294"/>
        <source>Exploration mode: Use W, S, A and D keys to go forward, backward or move sideways</source>
        <translation>Tryb przeglądania: użyj klawiszy W, S, A i D do poruszania się w górę, dół, prawo i lewo</translation>
    </message>
    <message>
        <location filename="../../src/glwidget.cpp" line="334"/>
        <source>Orbital mode: Move around the antenna by dragging it</source>
        <translation>Orbital mode: Obróć antenę</translation>
    </message>
    <message>
        <location filename="../../src/glwidget.cpp" line="395"/>
        <source>QAntenna - DataManager</source>
        <translation>QAntena - Menadżer danych</translation>
    </message>
    <message>
        <location filename="../../src/glwidget.cpp" line="396"/>
        <source>I can not create the OpenGL list for the grid</source>
        <translation>Nie mogę utworzyć listy OpenGL </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="161"/>
        <source>Welcome to</source>
        <translation>Witamy w</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="325"/>
        <location filename="../../src/ui/mainwindow.cpp" line="446"/>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="325"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="498"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="500"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="544"/>
        <source>([0-9]+) *x *([0-9]+)</source>
        <translation>([0-9]+) *x *([0-9]+)</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="548"/>
        <source>Render into file</source>
        <translation>Rendruj do pliku</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="549"/>
        <source>Enter the desired resolution:</source>
        <translation>Wpisz żądaną rozdzielczość:</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="550"/>
        <source>%1 x %2</source>
        <translation>%1 x %2</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="588"/>
        <source>%1 file (*.%2);;</source>
        <translation>%1 plik (*.%2);;</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="596"/>
        <source>Save Image As</source>
        <translation>Zapisz obraz jako</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="613"/>
        <source>Rendering to &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
        <translation>Rendrowanie do &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="618"/>
        <source>Unable to save %1.</source>
        <translation>Nie można zapisać %1.</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="629"/>
        <source>Rendering to clipboard... </source>
        <translation>Rendrowanie do schowka...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="257"/>
        <source>Calculating...</source>
        <translation>Obiczanie...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="279"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="286"/>
        <source>Some antennas need to be calculated</source>
        <translation>Dla którejś z anten nadal trzeba dokonać obliczeń </translation>
    </message>
</context>
<context>
    <name>MainWindowQAntenna</name>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="19"/>
        <source>QAntenna</source>
        <translation>QAntenna</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="92"/>
        <source>Open file...</source>
        <translation>Otwórz plik...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="95"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="116"/>
        <source>Close file...</source>
        <translation>Zamknij plik...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="119"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="132"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="164"/>
        <source>A</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="242"/>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="268"/>
        <source>[Path]</source>
        <translation>[Ścieżka]</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="273"/>
        <source>[Index]</source>
        <translation>[Indeks]</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="310"/>
        <source>Calculate at opening</source>
        <translation>Obliczaj przy otwieraniu</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="350"/>
        <source>Log</source>
        <translation>Dziennik</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="378"/>
        <source>History:</source>
        <translation>Historia:</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="388"/>
        <source>Clean history</source>
        <translation>Wyczyść historię</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="473"/>
        <source>Visualization</source>
        <translation>Wizualizacja</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="757"/>
        <source>Modes</source>
        <translation>Tryby</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="780"/>
        <source>Surface</source>
        <translation>Powierzchnia</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="787"/>
        <source>Spheres</source>
        <translation>Sfera</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="794"/>
        <source>Mesh</source>
        <translation>Siatkowa (mesh)</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="801"/>
        <source>Volumetric</source>
        <translation>Objętościowy</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="808"/>
        <source>Show grid</source>
        <translation>Pokazuj siatkę</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="502"/>
        <source>Pattern scale</source>
        <translation>Skala wzoru</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="509"/>
        <source>Transparency</source>
        <translation>Przeźroczystość</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="516"/>
        <source>Spheres radius</source>
        <translation>Promień sfery</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="523"/>
        <source>Segment radius</source>
        <translation>Promień segmentu</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="676"/>
        <source>Minimum dB at the origin</source>
        <translation>Minimalna dB przy źródle</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="878"/>
        <source>&amp;Help</source>
        <translation>P&amp;omoc</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="896"/>
        <source>&amp;Tools</source>
        <translation>&amp;Narzędzia</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="885"/>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="912"/>
        <source>&amp;Quit</source>
        <translation>Wyjście &amp;Q</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="915"/>
        <source>Quit</source>
        <translation>Wyjście</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="918"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="926"/>
        <source>&amp;About...</source>
        <translation>O progr&amp;amie...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="929"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="937"/>
        <source>&amp;Open...</source>
        <translation>&amp;Otwórz...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="940"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="951"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="954"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="965"/>
        <source>C&amp;lose all</source>
        <translation>Zamknij &amp;wszystkie</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="976"/>
        <source>C&amp;alculate patterns</source>
        <translation>Przelicz odwzorow&amp;ania</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="979"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="987"/>
        <source>About &amp;Qt...</source>
        <translation>O &amp;Qt...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="995"/>
        <source>&amp;Render to file...</source>
        <translation>&amp;Rendruj do pliku...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="998"/>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1001"/>
        <source>Render to file</source>
        <translation>Rendruj do pliku</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1004"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1012"/>
        <source>Render to &amp;clipboard...</source>
        <translation>Rendruj do s&amp;chowka...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1015"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="453"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="247"/>
        <source> Frequency</source>
        <translation>Częstotliwość</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="252"/>
        <source> Calculated </source>
        <translation>Obliiczono</translation>
    </message>
</context>
<context>
    <name>NECContainer</name>
    <message>
        <location filename="../../src/neccontainer.cpp" line="225"/>
        <source>Rendering &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
        <translation>Rendrowanie &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/main.cpp" line="66"/>
        <source>Checking if there is OpenGL support in this machine</source>
        <translation>Sprawdzanie czy istnieje wsparcie OpenGL na Twoim komputerze</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="77"/>
        <source>Loading QAntenna</source>
        <translation>Ładowanie QAntenna</translation>
    </message>
</context>
<context>
    <name>QWidget</name>
    <message>
        <location filename="../../src/main.cpp" line="69"/>
        <source>We don&apos;t have OpenGL support</source>
        <translation>Brak wsparcia dla OpenGL</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="71"/>
        <source>There is no OpenGL support in your system.&lt;br&gt;Closing QAntenna</source>
        <translation>Nie masz zainstalowanego OpenGL w systemie &lt;br&gt; Zamykanie QAntenna</translation>
    </message>
    <message>
        <location filename="../../src/necinput.cpp" line="137"/>
        <source>While trying to insert a FR card, I could not find a GE card in order to put the first card in a right place</source>
        <translation>W czasie próby włożenia karty FR, nie można znaleźć działającej karty GE. Włóż pierwszą kartę we właściwe miejsce</translation>
    </message>
    <message>
        <location filename="../../src/necinput.cpp" line="982"/>
        <source>I could not create/open input.necin</source>
        <translation>Nie mogę utworzyć/otworzyć input.necin</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="117"/>
        <location filename="../../src/necinputparser.cpp" line="205"/>
        <source>The following line can not be parsed properly</source>
        <translation>Następująca linia nie może zostać prawidłowo sparsowana</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="119"/>
        <location filename="../../src/necinputparser.cpp" line="207"/>
        <source>The string list is</source>
        <translation>Ciąg listy jest</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="226"/>
        <location filename="../../src/necinputparser.cpp" line="234"/>
        <location filename="../../src/necinputparser.cpp" line="244"/>
        <source>QAntenna - NEC input parser</source>
        <translation>QAntenna - parser wejścia NEC</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="227"/>
        <source>The file does not exists</source>
        <translation>Plik nie istnieje</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="235"/>
        <source>I can not read the file</source>
        <translation>Nie mogę czytać pliku</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="245"/>
        <source>The file is empty</source>
        <translation>Plik jest pusty</translation>
    </message>
</context>
</TS>
